pdf_ocr_funtion_arn = "arn:aws:lambda:us-east-1:689835822208:function:ocr-pdf-dev-lambda"
img_ocr_funtion_arn = "arn:aws:lambda:us-east-1:689835822208:function:ocr-img-dev-lambda"

base_url = "https://cjuwzz07ri.execute-api.us-east-1.amazonaws.com/prod"
# base_url = "https://api.duke.ai/api"

duke_auto_lambda_arn = "arn:aws:lambda:us-east-1:689835822208:function:Bare-Duke-dev-Auto"
orchatect_auto_lambda_arn = "arn:aws:lambda:us-east-1:689835822208:function:Bare-Orchatect-dev-Auto"
ralock_auto_lambda_arn = "arn:aws:lambda:us-east-1:689835822208:function:Bare-Ralock-dev-Auto"
